@@ -1,5 +1,5 @@
 from django.contrib import admin
-from app.models import *
+from chatbot_session_flow.models import *
 
 # Register your models here.
 admin.site.register(Profile)
