@@ -1,4 +1,4 @@
-from .models import *
+from chatbot_session_flow.models import *
 
 def menu_links(request):
     links = Profile.objects.all()
