@@ -1,6 +1,6 @@
 from django.urls import re_path
-from app import views
-from .views import *
+from . import views
+from chatbot_session_flow.views import *
 
 urlpatterns = [
     re_path('sendTestMessage', views.sendWhatsappMessageViaNgumzo),
